# Create raw and normalized sets
# by Cristian R Munteanu - muntisa@gmail.com

library(MASS)

set.seed(500)

# read RAW data
data <- read.csv("ds.raw.csv",header=T)

# split 75-25%
index <- sample(1:nrow(data),round(0.75*nrow(data)))
train <- data[index,]
test <- data[-index,]

# write train and validation/test RAW datasets
write.table(train, file = "ds.raw.tr.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))
write.table(test, file = "ds.raw.ts.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))

# NORMALIZED data
maxs <- apply(data, 2, max) 
mins <- apply(data, 2, min)
scaled <- as.data.frame(scale(data, center = mins, scale = maxs - mins))
# write NORMALIZED dataset
write.table(scaled, file = "ds.norm.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))

# write train and test NORMALIZED datasets
train_ <- scaled[index,]
test_ <- scaled[-index,]
write.table(train_, file = "ds.norm.tr.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))
write.table(test_, file = "ds.norm.ts.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))
