library(MASS)

# read RAW data
data <- read.csv("ds.corr.raw.csv",header=T)

# set the seed = no of cases!
set.seed(as.integer(dim(data)[1]))

# split 75-25%
index <- sample(1:nrow(data),round(0.75*nrow(data)))
train <- data[index,]
test <- data[-index,]

# RAW files
# =============================================
# write train and validation/test raw datasets
write.table(train, file = "ds.corr.raw.tr.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))
write.table(test, file = "ds.corr.raw.ts.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))

# normalize data
maxs <- apply(data, 2, max) 
mins <- apply(data, 2, min)
scaled <- as.data.frame(scale(data, center = mins, scale = maxs - mins))

# write NORMALIZED dataset
write.table(scaled, file = "ds.corr.norm.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))

# write train and validation/test normalized datasets
train_ <- scaled[index,]
test_ <- scaled[-index,]
write.table(train_, file = "ds.corr.norm.tr.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))
write.table(test_, file = "ds.corr.norm.ts.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))
